@@ -27,6 +27,10 @@ public class vtkExtractCells extends vtkUnstructuredGridAlgorithm
   public void AddCellRange(int id0,int id1)
     { AddCellRange_4(id0,id1); }
 
+  private native int GetMTime_5();
+  public int GetMTime()
+    { return GetMTime_5(); }
+
   public vtkExtractCells() { super(); }
 
   public vtkExtractCells(long id) { super(id); }
