@@ -7,18 +7,14 @@ import vtk.*;
 public class vtkImageFFT extends vtkImageFourierFilter
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
     { return IsA_1(id0); }
 
-  private native int SplitExtent_2(int id0[],int id1[],int id2,int id3);
-  public int SplitExtent(int id0[],int id1[],int id2,int id3)
-    { return SplitExtent_2(id0,id1,id2,id3); }
-
   public vtkImageFFT() { super(); }
 
   public vtkImageFFT(long id) { super(id); }
