@@ -147,6 +147,10 @@ public class vtkSphereHandleRepresentation extends vtkHandleRepresentation
   public void Highlight(int id0)
     { Highlight_32(id0); }
 
+  private native void RegisterPickers_33();
+  public void RegisterPickers()
+    { RegisterPickers_33(); }
+
   public vtkSphereHandleRepresentation() { super(); }
 
   public vtkSphereHandleRepresentation(long id) { super(id); }
