@@ -35,6 +35,10 @@ public class vtkTreeReader extends vtkDataReader
   public void SetOutput(vtkTree id0)
     { SetOutput_4(id0); }
 
+  private native int ReadMeshSimple_5(String id0,vtkDataObject id1);
+  public int ReadMeshSimple(String id0,vtkDataObject id1)
+    { return ReadMeshSimple_5(id0,id1); }
+
   public vtkTreeReader() { super(); }
 
   public vtkTreeReader(long id) { super(id); }
